all: rename internal/safefilepath to internal/filepathlite

The safefilepath package was originally added to contain
the FromFS function. We subsequently added FromFS to path/filepath
as Localize. The safefilepath package now exists only to permit
the os package to import Localize.

Rename safefilepath to filepathlite to better indicate that it's
a low-dependency version of filepath.

Change-Id: I4c5f9b28e8581f841947b48c5cac9954cd0c9535
Reviewed-on: https://go-review.googlesource.com/c/go/+/581517
LUCI-TryBot-Result: Go LUCI <golang-scoped@luci-project-accounts.iam.gserviceaccount.com>
Reviewed-by: Ian Lance Taylor <iant@google.com>
diff --git a/src/go/build/deps_test.go b/src/go/build/deps_test.go
index a3ba809..14880d9 100644
--- a/src/go/build/deps_test.go
+++ b/src/go/build/deps_test.go
@@ -174,7 +174,7 @@
 	io/fs
 	< internal/testlog
 	< internal/poll
-	< internal/safefilepath
+	< internal/filepathlite
 	< os
 	< os/signal;
 
@@ -183,7 +183,7 @@
 
 	unicode, fmt !< net, os, os/signal;
 
-	os/signal, internal/safefilepath, STR
+	os/signal, internal/filepathlite, STR
 	< path/filepath
 	< io/ioutil;
 
diff --git a/src/internal/safefilepath/path_plan9.go b/src/internal/filepathlite/path_plan9.go
similarity index 93%
rename from src/internal/safefilepath/path_plan9.go
rename to src/internal/filepathlite/path_plan9.go
index 55627c5..91a95dd 100644
--- a/src/internal/safefilepath/path_plan9.go
+++ b/src/internal/filepathlite/path_plan9.go
@@ -2,7 +2,7 @@
 // Use of this source code is governed by a BSD-style
 // license that can be found in the LICENSE file.
 
-package safefilepath
+package filepathlite
 
 import "internal/bytealg"
 
diff --git a/src/internal/safefilepath/path_unix.go b/src/internal/filepathlite/path_unix.go
similarity index 94%
rename from src/internal/safefilepath/path_unix.go
rename to src/internal/filepathlite/path_unix.go
index 873d093..edad208 100644
--- a/src/internal/safefilepath/path_unix.go
+++ b/src/internal/filepathlite/path_unix.go
@@ -4,7 +4,7 @@
 
 //go:build unix || (js && wasm) || wasip1
 
-package safefilepath
+package filepathlite
 
 import "internal/bytealg"
 
diff --git a/src/internal/safefilepath/path_windows.go b/src/internal/filepathlite/path_windows.go
similarity index 98%
rename from src/internal/safefilepath/path_windows.go
rename to src/internal/filepathlite/path_windows.go
index b626196..3d7290b 100644
--- a/src/internal/safefilepath/path_windows.go
+++ b/src/internal/filepathlite/path_windows.go
@@ -2,7 +2,7 @@
 // Use of this source code is governed by a BSD-style
 // license that can be found in the LICENSE file.
 
-package safefilepath
+package filepathlite
 
 import (
 	"internal/bytealg"
diff --git a/src/os/dir.go b/src/os/dir.go
index dcc18e1..d75ac17 100644
--- a/src/os/dir.go
+++ b/src/os/dir.go
@@ -5,7 +5,7 @@
 package os
 
 import (
-	"internal/safefilepath"
+	"internal/filepathlite"
 	"io"
 	"io/fs"
 	"sort"
@@ -146,7 +146,7 @@
 			return err
 		}
 
-		fpath, err := safefilepath.Localize(path)
+		fpath, err := filepathlite.Localize(path)
 		if err != nil {
 			return err
 		}
@@ -157,7 +157,7 @@
 
 		// TODO(panjf2000): handle symlinks with the help of fs.ReadLinkFS
 		// 		once https://go.dev/issue/49580 is done.
-		//		we also need safefilepath.IsLocal from https://go.dev/cl/564295.
+		//		we also need filepathlite.IsLocal from https://go.dev/cl/564295.
 		if !d.Type().IsRegular() {
 			return &PathError{Op: "CopyFS", Path: path, Err: ErrInvalid}
 		}
diff --git a/src/os/file.go b/src/os/file.go
index ec8ad70..c3ee315 100644
--- a/src/os/file.go
+++ b/src/os/file.go
@@ -45,8 +45,8 @@
 
 import (
 	"errors"
+	"internal/filepathlite"
 	"internal/poll"
-	"internal/safefilepath"
 	"internal/testlog"
 	"io"
 	"io/fs"
@@ -766,7 +766,7 @@
 	if dir == "" {
 		return "", errors.New("os: DirFS with empty root")
 	}
-	name, err := safefilepath.Localize(name)
+	name, err := filepathlite.Localize(name)
 	if err != nil {
 		return "", ErrInvalid
 	}
diff --git a/src/path/filepath/path.go b/src/path/filepath/path.go
index 6c8a0aa..cd70c2b 100644
--- a/src/path/filepath/path.go
+++ b/src/path/filepath/path.go
@@ -13,7 +13,7 @@
 
 import (
 	"errors"
-	"internal/safefilepath"
+	"internal/filepathlite"
 	"io/fs"
 	"os"
 	"slices"
@@ -221,7 +221,7 @@
 //
 // The path returned by Localize will always be local, as reported by IsLocal.
 func Localize(path string) (string, error) {
-	return safefilepath.Localize(path)
+	return filepathlite.Localize(path)
 }
 
 // ToSlash returns the result of replacing each separator character
diff --git a/src/path/filepath/path_windows.go b/src/path/filepath/path_windows.go
index 6adb7d4..44037c4 100644
--- a/src/path/filepath/path_windows.go
+++ b/src/path/filepath/path_windows.go
@@ -5,7 +5,7 @@
 package filepath
 
 import (
-	"internal/safefilepath"
+	"internal/filepathlite"
 	"os"
 	"strings"
 	"syscall"
@@ -42,7 +42,7 @@
 		if part == "." || part == ".." {
 			hasDots = true
 		}
-		if safefilepath.IsReservedName(part) {
+		if filepathlite.IsReservedName(part) {
 			return false
 		}
 	}
diff --git a/src/internal/safefilepath/path.go b/src/internal/filepathlite/path.go
similarity index 86%
rename from src/internal/safefilepath/path.go
rename to src/internal/filepathlite/path.go
index c2cc6ce..b452987 100644
--- a/src/internal/safefilepath/path.go
+++ b/src/internal/filepathlite/path.go
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style
 // license that can be found in the LICENSE file.
 
-// Package safefilepath manipulates operating-system file paths.
-package safefilepath
+// Package filepathlite manipulates operating-system file paths.
+package filepathlite
 
 import (
 	"errors"